#!/usr/bin/env python
#coding:utf8 
"""
This script generates monthly calendars as a printable PDF table.
See http://fzu.cz/~dominecf/ for details.

Licensed under BSD
Filip Dominec 2013
"""

import calendar, datetime, sys, subprocess

from reportlab.lib import colors
from reportlab.platypus import SimpleDocTemplate, Table, TableStyle
from reportlab.lib.pagesizes import cm


if len(sys.argv) > 1:
    m = int(sys.argv[1])
else:
    m = datetime.date.today().month
    print "Using the current month; you may select it as the first parameter, e. g. 'cal.py 7'"

if len(sys.argv) > 2:
    y = int(sys.argv[2])
else:
    y = datetime.date.today().year
    print "Using the current year; you may select it as the second parameter, e. g. 'cal.py 7 2013'"

outname = "calendar_%d_%02d.tex" % (y, m)

doc = SimpleDocTemplate("calendar_%d_%02d.pdf" % (y, m))
doc.topMargin = 1.0*cm
doc.leftMargin = 1.0*cm
doc.rightMargin = 1.0*cm
doc.bottomMargin = 1.0*cm
elements = []

cal = calendar.Calendar()
#dnamelist = ['Po', 'Út', 'St', 'Ct', 'Pá', 'So', 'Ne']         # Czech
dnamelist = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']       # English

header = ["%d-%02d" % (y,m)] + ["%02d:00"%t for t in range(8, 22, 2)]
print "\nHeader (edit the source code to customize!):"
print header

## Generate the calendar table data
data =  [header]
line_count = 0
hilightlines = []
import itertools
for day in itertools.chain.from_iterable(cal.monthdatescalendar(y, m)): ## flatten the weeks in month
        if day.month != m: continue
        line_count+=1   
        if day.weekday() in (5,6): hilightlines.append(line_count)
        dayname = dnamelist[day.weekday()]
        data += [["%s %02d"%(dayname, day.day)]   +   ['']*(len(header)-1)]
data += [header]
t=Table(data, rowHeights=(.8*cm))
t.setStyle(TableStyle([
        ('ALIGN',(0,0),(-1,-1),'LEFT'),
        ('INNERGRID', (0,0), (-1,-1), 0.25, colors.black),
        ('BOX', (1,0), (-1,-1), 1.50, colors.black),
        #('BOX', (0,0), (-1,-1), 1.50, colors.black),
        ('BOX', (0,1), (-1,-2), 1.50, colors.black),
                       ]))
## Set layout and hilight
t._argW[0]=2.*cm
for a in range(1,len(header)): t._argW[a]=2.2*cm
for line in hilightlines:
    t.setStyle(TableStyle([
            ('BACKGROUND',(0,line),(-1,line), '#dddddd'),
            ]))
elements.append(t)
doc.build(elements)
